==> knative-model-4.5.0-sources.jar: io/fabric8/knative/eventing/v1alpha1/TriggerFluentImpl.java <==
package io.fabric8.knative.eventing.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import java.lang.Object;

public class TriggerFluentImpl<A extends TriggerFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements TriggerFluent<A>{

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private TriggerSpecBuilder spec;
    private TriggerStatusBuilder status;

    public TriggerFluentImpl(){
    }
    public TriggerFluentImpl(Trigger instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.get("metadata").remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public TriggerFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public TriggerFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public TriggerFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public TriggerFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public TriggerFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public TriggerSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public TriggerSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(TriggerSpec spec){
            _visitables.get("spec").remove(this.spec);
            if (spec!=null){ this.spec= new TriggerSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec != null;
    }

    public TriggerFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public TriggerFluent.SpecNested<A> withNewSpecLike(TriggerSpec item){
            return new SpecNestedImpl(item);
    }

    public TriggerFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public TriggerFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new TriggerSpecBuilder().build());
    }

    public TriggerFluent.SpecNested<A> editOrNewSpecLike(TriggerSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public TriggerStatus getStatus(){
            return this.status!=null?this.status.build():null;
    }

    public TriggerStatus buildStatus(){
            return this.status!=null?this.status.build():null;
    }

    public A withStatus(TriggerStatus status){
            _visitables.get("status").remove(this.status);
            if (status!=null){ this.status= new TriggerStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
    }

    public Boolean hasStatus(){
            return this.status != null;
    }

    public TriggerFluent.StatusNested<A> withNewStatus(){
            return new StatusNestedImpl();
    }

    public TriggerFluent.StatusNested<A> withNewStatusLike(TriggerStatus item){
            return new StatusNestedImpl(item);
    }

    public TriggerFluent.StatusNested<A> editStatus(){
            return withNewStatusLike(getStatus());
    }

    public TriggerFluent.StatusNested<A> editOrNewStatus(){
            return withNewStatusLike(getStatus() != null ? getStatus(): new TriggerStatusBuilder().build());
    }

    public TriggerFluent.StatusNested<A> editOrNewStatusLike(TriggerStatus item){
            return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            TriggerFluentImpl that = (TriggerFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<TriggerFluent.MetadataNested<N>> implements TriggerFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) TriggerFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends TriggerSpecFluentImpl<TriggerFluent.SpecNested<N>> implements TriggerFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final TriggerSpecBuilder builder;
    
            SpecNestedImpl(TriggerSpec item){
                    this.builder = new TriggerSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new TriggerSpecBuilder(this);
            }
    
    public N and(){
            return (N) TriggerFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}
    public class StatusNestedImpl<N> extends TriggerStatusFluentImpl<TriggerFluent.StatusNested<N>> implements TriggerFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final TriggerStatusBuilder builder;
    
            StatusNestedImpl(TriggerStatus item){
                    this.builder = new TriggerStatusBuilder(this, item);
            }
            StatusNestedImpl(){
                    this.builder = new TriggerStatusBuilder(this);
            }
    
    public N and(){
            return (N) TriggerFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus(){
            return and();
    }

}


}

==> knative-model-4.9.0-sources.jar: io/fabric8/knative/eventing/v1alpha1/TriggerFluentImpl.java <==
package io.fabric8.knative.eventing.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import java.lang.Object;

public class TriggerFluentImpl<A extends TriggerFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements TriggerFluent<A>{

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private TriggerSpecBuilder spec;
    private TriggerStatusBuilder status;

    public TriggerFluentImpl(){
    }
    public TriggerFluentImpl(Trigger instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.get("metadata").remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public TriggerFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public TriggerFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public TriggerFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public TriggerFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public TriggerFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public TriggerSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public TriggerSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(TriggerSpec spec){
            _visitables.get("spec").remove(this.spec);
            if (spec!=null){ this.spec= new TriggerSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec != null;
    }

    public TriggerFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public TriggerFluent.SpecNested<A> withNewSpecLike(TriggerSpec item){
            return new SpecNestedImpl(item);
    }

    public TriggerFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public TriggerFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new TriggerSpecBuilder().build());
    }

    public TriggerFluent.SpecNested<A> editOrNewSpecLike(TriggerSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public TriggerStatus getStatus(){
            return this.status!=null?this.status.build():null;
    }

    public TriggerStatus buildStatus(){
            return this.status!=null?this.status.build():null;
    }

    public A withStatus(TriggerStatus status){
            _visitables.get("status").remove(this.status);
            if (status!=null){ this.status= new TriggerStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
    }

    public Boolean hasStatus(){
            return this.status != null;
    }

    public TriggerFluent.StatusNested<A> withNewStatus(){
            return new StatusNestedImpl();
    }

    public TriggerFluent.StatusNested<A> withNewStatusLike(TriggerStatus item){
            return new StatusNestedImpl(item);
    }

    public TriggerFluent.StatusNested<A> editStatus(){
            return withNewStatusLike(getStatus());
    }

    public TriggerFluent.StatusNested<A> editOrNewStatus(){
            return withNewStatusLike(getStatus() != null ? getStatus(): new TriggerStatusBuilder().build());
    }

    public TriggerFluent.StatusNested<A> editOrNewStatusLike(TriggerStatus item){
            return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            TriggerFluentImpl that = (TriggerFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<TriggerFluent.MetadataNested<N>> implements TriggerFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) TriggerFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends TriggerSpecFluentImpl<TriggerFluent.SpecNested<N>> implements TriggerFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final TriggerSpecBuilder builder;
    
            SpecNestedImpl(TriggerSpec item){
                    this.builder = new TriggerSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new TriggerSpecBuilder(this);
            }
    
    public N and(){
            return (N) TriggerFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}
    public class StatusNestedImpl<N> extends TriggerStatusFluentImpl<TriggerFluent.StatusNested<N>> implements TriggerFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final TriggerStatusBuilder builder;
    
            StatusNestedImpl(TriggerStatus item){
                    this.builder = new TriggerStatusBuilder(this, item);
            }
            StatusNestedImpl(){
                    this.builder = new TriggerStatusBuilder(this);
            }
    
    public N and(){
            return (N) TriggerFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus(){
            return and();
    }

}


}
